###############################################################
# FRP QC TOOL
# May 2018
# Main
#
###############################################################

import arcpy
#import importlib, datetime
from logging.handlers import TimedRotatingFileHandler
import sys, os, re, datetime, FRPReport, FRPUtil, logging

def run_tool(gdbLoc, reportLoc, singleCheck="0"):

    # call once
    logger = FRPUtil.set_logger()
    logger.info("run_tool started.")
    appRoot = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

    arcpy.env.workspace = gdbLoc
    arcpy.env.overwriteOutput = True
    sys.argv = [gdbLoc, reportLoc, "", appRoot, "", "", False]  #gdb location, report location, table location.tool location, checks, topology gdb path, precheck error
    
    FRPUtil.get_featureclasses_tables(gdbLoc, "FRD_Spatial_Layers")
    
    if not FRPUtil.verifyHash():
        logger.info("ERROR: The FRP QC Tool code is not a genuine copy; it may be compromised. Please contact FEMA MIP HelpDesk miphelp@riskmapcds.com")
        arcpy.AddError("ERROR: The FRP QC Tool code is not a genuine copy; it may be compromised. Please contact FEMA MIP HelpDesk miphelp@riskmapcds.com")
        return False 
    
    report = FRPReport.FRPReport()
    reportLoc = report.create_report()
    sys.argv = [gdbLoc, reportLoc, "", appRoot, "", "", False, report]

    gdbCheck = FRPUtil.verify_gdb()    
    licenseCheck =  FRPUtil.verify_license()

    if gdbCheck == False:
        arcpy.AddError("ERROR: Only File Geodatabases can be submitted, checks will not be run.")
        report.no_run("Only File Geodatabases can be submitted to run tool.")

    elif licenseCheck == False:
        arcpy.AddError("ERROR: Must have 'Standard' or 'Advance' ArcGIS Desktop license level to run tool, checks will not be run.")
        report.no_run("Must have 'Standard' or 'Advance' and 'spatial abalysis extension' ArcGIS Desktop license level to run tool.")

    else:               
        try:
            checks = FRPUtil.get_checks(True) #precheck
            preCheckResults = True
            for check in checks:                    
                arcpy.env.workspace = gdbLoc
                sys.argv[4] = check

                checkClass = FRPUtil.load_class(check[3] + "." + check[3])
                preCheckResult = checkClass().run_check(sys.argv[3] + "\\Scripts\\" + check[3]);
                if preCheckResult == False and sys.argv[4][2] <> "Warning":
                    preCheckResults = False
                       
            if preCheckResults == False:
                arcpy.AddError("ERROR: Prechecks have failed, remaining checks will not be run.")
                report.no_run()
            else:
                checks = FRPUtil.get_checks(False) #regular check
                for check in checks:
                    arcpy.env.workspace = gdbLoc
                    sys.argv[4] = check          
                    checkClass = FRPUtil.load_class(check[3] + "." + check[3])
                    result = checkClass().run_check(sys.argv[3] + "\\Scripts\\" + check[3]);

            report.end_report()    
        except ValueError:
                raise
    
    arcpy.AddMessage("Analysis complete. See the generated report for details: " + sys.argv[1])

if __name__ == '__main__':
    #run_tool(arcpy.GetParameterAsText(0), arcpy.GetParameterAsText(1))
    run_tool("C:\Temp\FRD_08015C_20151230\FRD_08015C_20151230.gdb", "C:\Temp\FRD_08015C_20151230") 